@@ -9,9 +9,13 @@
 #' @importFrom rstudioapi insertText
 insert_template <- function(){
   # This function is not included in the unit test
-  fpath <- system.file("templates", "template_spin.txt", package="repana")
+  fpath <- trimws(config::get("template"))
+  if (! identical(file.exists(fpath),TRUE)){
+    fpath <- system.file("templates", "template_spin.txt", package="repana")
+  }
+
   txt <- readLines(fpath)
   txt <- paste(txt, collapse  = "\n")
-  txt <- gsub("XXXXX", format(Sys.Date()),txt)
+  txt <- gsub("\\[INSERT DATE\\]", format(Sys.Date()),txt)
   rstudioapi::insertText(txt)
 }
